@@ -1,8 +1,9 @@
 /* GNOME DB library
- * Copyright (C) 1999-2002 The GNOME Foundation.
+ * Copyright (C) 1999 - 2005 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -20,11 +21,11 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include "gnome-db-decl.h"
 #include <libgda/gda-config.h>
-#include <libgnomedb/gnome-db-config.h>
 #include <libgnomedb/gnome-db-data-source-selector.h>
 #include <libgnomedb/gnome-db-dsn-config-druid.h>
-#include <libgnomedb/gnome-db-i18n.h>
+#include <glib/gi18n-lib.h>
 #include <libgnomedb/gnome-db-login.h>
 #include <libgnomedb/gnome-db-util.h>
 #include <gtk/gtklabel.h>
@@ -32,10 +33,12 @@
 #include <gtk/gtkstock.h>
 
 struct _GnomeDbLoginPrivate {
-	gchar *dsn_name;
+	gchar     *dsn_name;
+	GtkWidget *dsn_label;
 	GtkWidget *dsn_entry;
 	GtkWidget *create_dsn_button;
-	gboolean hiding_button;
+	gboolean   hiding_button;
+	gboolean   hiding_dsn;
 	GtkWidget *username_entry;
 	GtkWidget *password_entry;
 };
@@ -99,6 +102,7 @@ gnome_db_login_init (GnomeDbLogin *login, GnomeDbLoginClass *klass)
 	login->priv = g_new0 (GnomeDbLoginPrivate, 1);
 	login->priv->dsn_name = NULL;
 	login->priv->hiding_button = TRUE;
+	login->priv->hiding_dsn = FALSE;
 }
 
 static void
@@ -188,20 +192,6 @@ gnome_db_login_get_type (void)
 static void
 druid_finished_cb (GnomeDbDsnConfigDruid *druid, gboolean error, GnomeDbLogin *login)
 {
-	const GdaDataSourceInfo *dsn_info;
-
-	if (!error) {
-		dsn_info = gnome_db_dsn_config_druid_get_dsn (druid);
-		if (dsn_info) {
-			gnome_db_config_save_data_source (dsn_info->name,
-							  dsn_info->provider,
-							  dsn_info->cnc_string,
-							  dsn_info->description,
-							  dsn_info->username,
-							  dsn_info->password);
-		}
-	}
-
 	gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (druid)));
 	gtk_widget_set_sensitive (gtk_widget_get_toplevel (GTK_WIDGET (login)), TRUE);
 }
@@ -255,6 +245,7 @@ gnome_db_login_construct (GnomeDbLogin *login, const gchar *dsn)
 	gtk_label_set_selectable (GTK_LABEL (label), FALSE);
         gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
+	login->priv->dsn_label = label;
 	login->priv->dsn_entry = gnome_db_data_source_selector_new (dsn);
 	gtk_widget_show (login->priv->dsn_entry);
 	gtk_table_attach (GTK_TABLE (table), login->priv->dsn_entry, 1, 2, 0, 1,
@@ -410,12 +401,40 @@ void
 gnome_db_login_set_enable_create_button (GnomeDbLogin *login, gboolean enable)
 {
 	g_return_if_fail (GNOME_DB_IS_LOGIN (login));
+	
+	if (login->priv->hiding_button != enable)
+		return;
 
-	if (login->priv->hiding_button && enable) {
-		login->priv->hiding_button = FALSE;
-		gtk_widget_show (login->priv->create_dsn_button);
-	} else if (!login->priv->hiding_button && !enable) {
-		login->priv->hiding_button = TRUE;
+	login->priv->hiding_button = !enable;
+	if (enable) {
+		if (!login->priv->hiding_dsn)
+			gtk_widget_show (login->priv->create_dsn_button);
+	} else 
+		gtk_widget_hide (login->priv->create_dsn_button);
+}
+
+/**
+ * gnome_db_login_set_show_dsn_selector
+ * @login: A #GnomeDbLogin widget.
+ * @show:
+ *
+ * Show/hide the combo box which allows to select the datasource to log into.
+ */
+void
+gnome_db_login_set_show_dsn_selector (GnomeDbLogin *login, gboolean show)
+{
+	g_return_if_fail (GNOME_DB_IS_LOGIN (login));
+
+	login->priv->hiding_dsn = !show;
+	if (show) {
+		gtk_widget_show (login->priv->dsn_entry);
+		gtk_widget_show (login->priv->dsn_label);
+		if (!login->priv->hiding_button)
+			gtk_widget_show (login->priv->create_dsn_button);
+	}
+	else {
+		gtk_widget_hide (login->priv->dsn_entry);
+		gtk_widget_hide (login->priv->dsn_label);
 		gtk_widget_hide (login->priv->create_dsn_button);
 	}
 }
